durationtools.positive_integer_to_implied_prolation_multiplier
==============================================================

.. autofunction:: abjad.tools.durationtools.positive_integer_to_implied_prolation_multiplier.positive_integer_to_implied_prolation_multiplier
